@@ -9,23 +9,22 @@ from numpy import ndarray
 from pydantic import BaseModel, Field
 from arductl.models import Mission, ArduStackConfig
 
-from staliro.options import StaliroOptions
-from staliro.optimizers import Optimizer, Run
-from staliro.results import StaliroResult
-
+from staliro.options import Options
+from staliro.optimizers import Optimizer
 from staliro.specification import Specification
 
 from .config import ArduPilotTestConfig
+from .blackbox import MissionFactory
 from partx.models import PartitioningOptions
 
 path.append(getcwd())
 
 
 class Module(BaseModel):
-    specification: Specification
-    optimizer: Optimizer[Run]
-    options: StaliroOptions
-    mission_factory: Optional[Callable[[ndarray, ndarray, ndarray], Mission]] = None
+    specification: Callable
+    optimizer: Optimizer[Any]
+    options: Options
+    mission_factory: Optional[MissionFactory] = None
     stack_config: ArduStackConfig = Field(default_factory=ArduStackConfig)
     config: ArduPilotTestConfig = Field(default_factory=ArduPilotTestConfig)
 
